@@ -22,9 +22,6 @@ class AIHClient:
             raise AIHE.AIHClientException('AIHClient has not been initialized yet.')
         
     
-    
-    
-    
     def __init__(self, environment:str, client_id:str, client_secret:str):
         """
         IN: environment (str)   - Defines where the client should connect to.
@@ -44,20 +41,14 @@ class AIHClient:
         self._update_token()
     
     
-    
-    
-    
     def _is_expired(self):
         """
         Checks if the Bearer token for the OAuth2 connection is expired
         """
         
-        return time.time() > self.expires_at
+        return time.time() > self.expires_at - 10000
   
     
-    
-    
-    
     def _update_token(self):
         """
         Gets a new Bearer token.
@@ -75,9 +66,6 @@ class AIHClient:
             raise AIHE.AIHClientException('Could not get token. Please check the token URL.')
      
         
-            
-            
-            
     def _get(self, api:str, endpoint:str, parameters:dict={}):
         """
         Sends a HTTPS GET request for the given endpoint.
@@ -107,7 +95,6 @@ class AIHClient:
             raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}')
         
 
-            
     def _put(self, api:str, endpoint:str, data:dict):
         """
         Sends a HTTPS PUT request for the given endpoint.
@@ -129,8 +116,6 @@ class AIHClient:
             raise AIHE.AIHClientException(f'PUT request failed: {response.status_code}\n{response.text}')
         
         
-        
-        
     def _post(self, api:str, endpoint:str, data:dict):
         """
         Sends a HTTPS POST request for the given endpoint.
@@ -239,7 +224,6 @@ class AIHClient:
                 
         return response.content
 
-    
 
     def _upload_media(self, container, file, name):
         """
@@ -265,13 +249,4 @@ class AIHClient:
         
         return response.json()
         
-        
-        
-        
-        
-        
-        
-        
-        
-        
         
\ No newline at end of file
