@@ -5,7 +5,6 @@ class PanoramicTour(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/panoramic-tours'
     
     
@@ -17,10 +16,10 @@ class PanoramicTour(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             self.value = self.value['panoramicTour']
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['panoramicTours']
         
         return self
@@ -32,7 +31,7 @@ class PanoramicTour(v1Object):
         To put the updates that have been made.
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['panoramicTour']['id']
         
         return self
